require('circle.lua')
require('sound_manager.lua')

CircleManager = {
	defaultMaxRadius = 500,
	defaultCircleSpeed = 20,
	defaultCircleColor = { r = 255, g = 155, b = 55, a = 255 },
	
	circles = {},
	
	addCircle = function(x,y)
		table.insert(
			CircleManager.circles,
			Circle.create(x,y,CircleManager.defaultMaxRadius,CircleManager.defaultCircleSpeed)
		);
	end,
	
	resolveCollisions = function()
		for i,circle1 in ipairs(CircleManager.circles) do
			for j,circle2 in ipairs(CircleManager.circles) do
				if(circle1 ~= circle2) then
					if(circle1:isCollided(circle2)) then
						circle1:reverse();
						SoundManager.playSound(circle1.radius);
					end
				end
			end
		end
	end,
	
	update = function(dt)
		for i,circle in ipairs(CircleManager.circles) do
			circle:update(dt);
		end
	end,
	
	draw = function()
		love.graphics.setColor(
			CircleManager.defaultCircleColor.r,
			CircleManager.defaultCircleColor.g,
			CircleManager.defaultCircleColor.b,
			CircleManager.defaultCircleColor.a
		);
		
		for i,circle in ipairs(CircleManager.circles) do
			love.graphics.circle("line",circle.x,circle.y,circle.radius,50);
		end
	end,
	
	clear = function()
		CircleManager.circles = {}
	end
};
